@@ -17,7 +17,6 @@
 #include <QCommandLineParser>
 #include <QApplication>
 #include <QObject>
-#include <QSettings>
 #include <QLockFile>
 #include <QStandardPaths>
 #include <QtGlobal>
@@ -60,7 +59,7 @@ int main(int argc, char **argv) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
 	app.setDesktopFileName("io.github.Qalculate.qalculate-qt");
 #endif
-	app.setApplicationVersion("5.3.0");
+	app.setApplicationVersion("5.5.0");
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 	app.setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
@@ -145,7 +144,7 @@ int main(int argc, char **argv) {
 		if(lockFile.error() == QLockFile::LockFailedError) {
 			bool ami_changed = false;
 			if(settings->allow_multiple_instances < 0 && parser->value(fOption).isEmpty() && parser->value(wOption).isEmpty() && parser->positionalArguments().isEmpty()) {
-				settings->allow_multiple_instances = (QMessageBox::question(NULL, QString("Allow multiple instances?"), QApplication::tr("By default, only one instance (one main window) of %1 is allowed.\n\nIf multiple instances are opened simultaneously, only the definitions (variables, functions, etc.), mode, preferences, and history of the last closed window will be saved.\n\nDo you, despite this, want to change the default behavior and allow multiple simultaneous instances?").arg("Qalculate!"), QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes);
+				settings->allow_multiple_instances = (QMessageBox::question(NULL, QApplication::tr("Allow multiple instances?"), QApplication::tr("By default, only one instance (one main window) of %1 is allowed.\n\nIf multiple instances are opened simultaneously, only the definitions (variables, functions, etc.), mode, preferences, and history of the last closed window will be saved.\n\nDo you, despite this, want to change the default behavior and allow multiple simultaneous instances?").arg("Qalculate!"), QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes);
 				ami_changed = true;
 				if(settings->allow_multiple_instances) {
 					QLocalSocket socket;
@@ -206,6 +205,7 @@ int main(int argc, char **argv) {
 	settings->loadPreferences();
 
 	if(!parser->value(wOption).isEmpty()) settings->loadWorkspace(parser->value(wOption).toLocal8Bit().data());
+	if(settings->disable_cursor_blinking) app.setCursorFlashTime(0);
 
 	CALCULATOR->loadExchangeRates();
 
@@ -262,6 +262,7 @@ int main(int argc, char **argv) {
 	}
 	win->setCommandLineParser(parser);
 	win->show();
+
 	app.processEvents();
 	win->initFinished();
 
